@@ -3,5 +3,7 @@ pub mod cost_scaling_push_relabel;
 pub mod lca;
 pub mod maximum_flow;
 pub mod min_cost_flow;
+pub mod re_rooting;
 pub mod shortest_path;
 pub mod strongly_connected_components;
+pub mod topological_sort;
